@@ -13,7 +13,7 @@ def push_branch(m:str,b:str,url:str) -> str:
     try:    
         cmd_remote = "git remote add origin {0}".format(url)
         cmd_branch = "git checkout {} ".format(b)
-        cmd_message = "git commit -m {}".format(m)
+        cmd_message = 'git commit -m "{}"'.format(m)
         cmd_push = "git push origin {}".format(b)
         if(b=="master" or b=="main" and m=="initial commit"):
             subprocess.getoutput('git init')
